Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the data v1 API group +kubebuilder:object:generate=true +groupName=data.kubeai.alibabacloud.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "data.kubeai.alibabacloud.com", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ExternalUser ¶
type ExternalUser struct {
AuthType string `json:"authType,omitempty"`
Uid string `json:"uid,omitempty"`
Name string `json:"name,omitempty"`
}
func (*ExternalUser) DeepCopy ¶
func (in *ExternalUser) DeepCopy() *ExternalUser
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ExternalUser.
func (*ExternalUser) DeepCopyInto ¶
func (in *ExternalUser) DeepCopyInto(out *ExternalUser)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type K8sRoleBinding ¶
type K8sRoleBinding struct {
metav1.ObjectMeta `json:",inline"`
RoleName string `json:"roleName,omitempty"`
}
func (*K8sRoleBinding) DeepCopy ¶
func (in *K8sRoleBinding) DeepCopy() *K8sRoleBinding
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new K8sRoleBinding.
func (*K8sRoleBinding) DeepCopyInto ¶
func (in *K8sRoleBinding) DeepCopyInto(out *K8sRoleBinding)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type K8sServiceAccount ¶
type K8sServiceAccount struct {
metav1.ObjectMeta `json:",inline"`
RoleBindings []K8sRoleBinding `json:"roleBindings,omitempty"`
ClusterRoleBindings []K8sRoleBinding `json:"clusterRoleBindings,omitempty"`
}
func (*K8sServiceAccount) DeepCopy ¶
func (in *K8sServiceAccount) DeepCopy() *K8sServiceAccount
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new K8sServiceAccount.
func (*K8sServiceAccount) DeepCopyInto ¶
func (in *K8sServiceAccount) DeepCopyInto(out *K8sServiceAccount)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type User ¶
type User struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec UserSpec `json:"spec,omitempty"`
Status UserStatus `json:"status,omitempty"`
}
User is the Schema for the users API
func (*User) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new User.
func (*User) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*User) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type UserGroup ¶
type UserGroup struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec UserGroupSpec `json:"spec,omitempty"`
Status UserGroupStatus `json:"status,omitempty"`
}
User is the Schema for the users API
func (*UserGroup) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserGroup.
func (*UserGroup) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*UserGroup) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type UserGroupList ¶
type UserGroupList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []UserGroup `json:"items"`
}
UserGroupList contains a list of UserGroup
func (*UserGroupList) DeepCopy ¶
func (in *UserGroupList) DeepCopy() *UserGroupList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserGroupList.
func (*UserGroupList) DeepCopyInto ¶
func (in *UserGroupList) DeepCopyInto(out *UserGroupList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*UserGroupList) DeepCopyObject ¶
func (in *UserGroupList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type UserGroupSpec ¶
type UserGroupSpec struct {
// Foo is an example field of User. Edit User_types.go to remove/update
QuotaNames []string `json:"quotaNames,omitempty"`
DefaultRoles []string `json:"defaultRoles,omitempty"`
DefaultClusterRoles []string `json:"defaultClusterRoles,omitempty"`
}
UserGroupSpec defines the desired state of UserGroup
func (*UserGroupSpec) DeepCopy ¶
func (in *UserGroupSpec) DeepCopy() *UserGroupSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserGroupSpec.
func (*UserGroupSpec) DeepCopyInto ¶
func (in *UserGroupSpec) DeepCopyInto(out *UserGroupSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UserGroupStatus ¶
type UserGroupStatus struct {
}
UserStatus defines the observed state of User
func (*UserGroupStatus) DeepCopy ¶
func (in *UserGroupStatus) DeepCopy() *UserGroupStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserGroupStatus.
func (*UserGroupStatus) DeepCopyInto ¶
func (in *UserGroupStatus) DeepCopyInto(out *UserGroupStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UserList ¶
type UserList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []User `json:"items"`
}
UserList contains a list of User
func (*UserList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserList.
func (*UserList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*UserList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type UserSpec ¶
type UserSpec struct {
// Foo is an example field of User. Edit User_types.go to remove/update
UserName string `json:"userName,omitempty"`
UserId string `json:"userId,omitempty"`
Password string `json:"password,omitempty"`
Aliuid string `json:"aliuid,omitempty"`
ExternalUser ExternalUser `json:"externalUser,omitempty"`
ApiRoles []string `json:"apiRoles,omitempty"`
Groups []string `json:"groups,omitempty"`
K8sServiceAccount K8sServiceAccount `json:"k8sServiceAccount,omitempty"`
Deletable bool `json:"deletable,omitempty"`
}
UserSpec defines the desired state of User
func (*UserSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserSpec.
func (*UserSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UserStatus ¶
type UserStatus struct {
}
UserStatus defines the observed state of User
func (*UserStatus) DeepCopy ¶
func (in *UserStatus) DeepCopy() *UserStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserStatus.
func (*UserStatus) DeepCopyInto ¶
func (in *UserStatus) DeepCopyInto(out *UserStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.