Documentation
¶
Index ¶
Constants ¶
const ( EnvSLSEndpoint = "SLS_ENDPOINT" EnvSLSKeyID = "SLS_KEY_ID" EnvSLSKeySecret = "SLS_KEY_SECRET" EnvSLSProject = "SLS_PROJECT" EnvSLSLogStore = "SLS_LOG_STORE" )
Constants down below defines configurations to initialize a sls backend storage service, user should set sls environment variables in Dockerfile or deployment manifests files, for security user should better init environment variables by referencing Secret key as down below: spec:
containers:
- name: xxx-container
image: xxx
env:
- name: SLS_ENDPOINT
valueFrom:
secretKeyRef:
name: my-sls-secret
key: endpoint
Variables ¶
This section is empty.
Functions ¶
func GetSLSClient ¶
func NewSLSEventBackend ¶
func NewSLSEventBackend() backends.EventStorageBackend
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.