Documentation
¶
Index ¶
- Variables
- func RegisterImageServiceServer(s grpc.ServiceRegistrar, srv ImageServiceServer)
- type CommitRequest
- func (*CommitRequest) Descriptor() ([]byte, []int)deprecated
- func (x *CommitRequest) GetContainerID() string
- func (x *CommitRequest) GetImage() string
- func (*CommitRequest) ProtoMessage()
- func (x *CommitRequest) ProtoReflect() protoreflect.Message
- func (x *CommitRequest) Reset()
- func (x *CommitRequest) String() string
- type CommitResponse
- type ImageServiceClient
- type ImageServiceServer
- type PushRequest
- func (*PushRequest) Descriptor() ([]byte, []int)deprecated
- func (x *PushRequest) GetImage() string
- func (x *PushRequest) GetPassword() string
- func (x *PushRequest) GetUsername() string
- func (*PushRequest) ProtoMessage()
- func (x *PushRequest) ProtoReflect() protoreflect.Message
- func (x *PushRequest) Reset()
- func (x *PushRequest) String() string
- type PushResponse
- type UnimplementedImageServiceServer
- func (UnimplementedImageServiceServer) CommitImage(context.Context, *CommitRequest) (*CommitResponse, error)
- func (UnimplementedImageServiceServer) PushImage(context.Context, *PushRequest) (*PushResponse, error)
- func (UnimplementedImageServiceServer) Version(context.Context, *VersionRequest) (*VersionResponse, error)
- type UnsafeImageServiceServer
- type VersionRequest
- type VersionResponse
Constants ¶
This section is empty.
Variables ¶
var File_service_proto protoreflect.FileDescriptor
var ImageService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "v1beta1.ImageService", HandlerType: (*ImageServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "Version", Handler: _ImageService_Version_Handler, }, { MethodName: "CommitImage", Handler: _ImageService_CommitImage_Handler, }, { MethodName: "PushImage", Handler: _ImageService_PushImage_Handler, }, }, Streams: []grpc.StreamDesc{}, Metadata: "service.proto", }
ImageService_ServiceDesc is the grpc.ServiceDesc for ImageService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterImageServiceServer ¶
func RegisterImageServiceServer(s grpc.ServiceRegistrar, srv ImageServiceServer)
Types ¶
type CommitRequest ¶
type CommitRequest struct {
ContainerID string `protobuf:"bytes,1,opt,name=containerID,proto3" json:"containerID,omitempty"`
Image string `protobuf:"bytes,2,opt,name=image,proto3" json:"image,omitempty"`
// contains filtered or unexported fields
}
func (*CommitRequest) Descriptor
deprecated
func (*CommitRequest) Descriptor() ([]byte, []int)
Deprecated: Use CommitRequest.ProtoReflect.Descriptor instead.
func (*CommitRequest) GetContainerID ¶
func (x *CommitRequest) GetContainerID() string
func (*CommitRequest) GetImage ¶
func (x *CommitRequest) GetImage() string
func (*CommitRequest) ProtoMessage ¶
func (*CommitRequest) ProtoMessage()
func (*CommitRequest) ProtoReflect ¶
func (x *CommitRequest) ProtoReflect() protoreflect.Message
func (*CommitRequest) Reset ¶
func (x *CommitRequest) Reset()
func (*CommitRequest) String ¶
func (x *CommitRequest) String() string
type CommitResponse ¶
type CommitResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*CommitResponse) Descriptor
deprecated
func (*CommitResponse) Descriptor() ([]byte, []int)
Deprecated: Use CommitResponse.ProtoReflect.Descriptor instead.
func (*CommitResponse) GetResult ¶
func (x *CommitResponse) GetResult() string
func (*CommitResponse) ProtoMessage ¶
func (*CommitResponse) ProtoMessage()
func (*CommitResponse) ProtoReflect ¶
func (x *CommitResponse) ProtoReflect() protoreflect.Message
func (*CommitResponse) Reset ¶
func (x *CommitResponse) Reset()
func (*CommitResponse) String ¶
func (x *CommitResponse) String() string
type ImageServiceClient ¶
type ImageServiceClient interface {
// Version returns the image service version
Version(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*VersionResponse, error)
// CommitImage in local
CommitImage(ctx context.Context, in *CommitRequest, opts ...grpc.CallOption) (*CommitResponse, error)
// PushImage to ACR
PushImage(ctx context.Context, in *PushRequest, opts ...grpc.CallOption) (*PushResponse, error)
}
ImageServiceClient is the client API for ImageService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewImageServiceClient ¶
func NewImageServiceClient(cc grpc.ClientConnInterface) ImageServiceClient
type ImageServiceServer ¶
type ImageServiceServer interface {
// Version returns the image service version
Version(context.Context, *VersionRequest) (*VersionResponse, error)
// CommitImage in local
CommitImage(context.Context, *CommitRequest) (*CommitResponse, error)
// PushImage to ACR
PushImage(context.Context, *PushRequest) (*PushResponse, error)
// contains filtered or unexported methods
}
ImageServiceServer is the server API for ImageService service. All implementations must embed UnimplementedImageServiceServer for forward compatibility
type PushRequest ¶
type PushRequest struct {
Image string `protobuf:"bytes,1,opt,name=image,proto3" json:"image,omitempty"`
Username string `protobuf:"bytes,2,opt,name=username,proto3" json:"username,omitempty"`
Password string `protobuf:"bytes,3,opt,name=password,proto3" json:"password,omitempty"`
// contains filtered or unexported fields
}
func (*PushRequest) Descriptor
deprecated
func (*PushRequest) Descriptor() ([]byte, []int)
Deprecated: Use PushRequest.ProtoReflect.Descriptor instead.
func (*PushRequest) GetImage ¶
func (x *PushRequest) GetImage() string
func (*PushRequest) GetPassword ¶
func (x *PushRequest) GetPassword() string
func (*PushRequest) GetUsername ¶
func (x *PushRequest) GetUsername() string
func (*PushRequest) ProtoMessage ¶
func (*PushRequest) ProtoMessage()
func (*PushRequest) ProtoReflect ¶
func (x *PushRequest) ProtoReflect() protoreflect.Message
func (*PushRequest) Reset ¶
func (x *PushRequest) Reset()
func (*PushRequest) String ¶
func (x *PushRequest) String() string
type PushResponse ¶
type PushResponse struct {
Result string `protobuf:"bytes,1,opt,name=result,proto3" json:"result,omitempty"`
// contains filtered or unexported fields
}
func (*PushResponse) Descriptor
deprecated
func (*PushResponse) Descriptor() ([]byte, []int)
Deprecated: Use PushResponse.ProtoReflect.Descriptor instead.
func (*PushResponse) GetResult ¶
func (x *PushResponse) GetResult() string
func (*PushResponse) ProtoMessage ¶
func (*PushResponse) ProtoMessage()
func (*PushResponse) ProtoReflect ¶
func (x *PushResponse) ProtoReflect() protoreflect.Message
func (*PushResponse) Reset ¶
func (x *PushResponse) Reset()
func (*PushResponse) String ¶
func (x *PushResponse) String() string
type UnimplementedImageServiceServer ¶
type UnimplementedImageServiceServer struct {
}
UnimplementedImageServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedImageServiceServer) CommitImage ¶
func (UnimplementedImageServiceServer) CommitImage(context.Context, *CommitRequest) (*CommitResponse, error)
func (UnimplementedImageServiceServer) PushImage ¶
func (UnimplementedImageServiceServer) PushImage(context.Context, *PushRequest) (*PushResponse, error)
func (UnimplementedImageServiceServer) Version ¶
func (UnimplementedImageServiceServer) Version(context.Context, *VersionRequest) (*VersionResponse, error)
type UnsafeImageServiceServer ¶
type UnsafeImageServiceServer interface {
// contains filtered or unexported methods
}
UnsafeImageServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to ImageServiceServer will result in compilation errors.
type VersionRequest ¶
type VersionRequest struct {
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*VersionRequest) Descriptor
deprecated
func (*VersionRequest) Descriptor() ([]byte, []int)
Deprecated: Use VersionRequest.ProtoReflect.Descriptor instead.
func (*VersionRequest) GetVersion ¶
func (x *VersionRequest) GetVersion() string
func (*VersionRequest) ProtoMessage ¶
func (*VersionRequest) ProtoMessage()
func (*VersionRequest) ProtoReflect ¶
func (x *VersionRequest) ProtoReflect() protoreflect.Message
func (*VersionRequest) Reset ¶
func (x *VersionRequest) Reset()
func (*VersionRequest) String ¶
func (x *VersionRequest) String() string
type VersionResponse ¶
type VersionResponse struct {
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
// contains filtered or unexported fields
}
func (*VersionResponse) Descriptor
deprecated
func (*VersionResponse) Descriptor() ([]byte, []int)
Deprecated: Use VersionResponse.ProtoReflect.Descriptor instead.
func (*VersionResponse) GetVersion ¶
func (x *VersionResponse) GetVersion() string
func (*VersionResponse) ProtoMessage ¶
func (*VersionResponse) ProtoMessage()
func (*VersionResponse) ProtoReflect ¶
func (x *VersionResponse) ProtoReflect() protoreflect.Message
func (*VersionResponse) Reset ¶
func (x *VersionResponse) Reset()
func (*VersionResponse) String ¶
func (x *VersionResponse) String() string